@@ -27,7 +27,7 @@ is a list of CIDR ranges to automatically blacklist, and always return
 a "SPAM" result from.
 
 The options are discussed as part of the L<Blog::Server::API>, in the
-section L<Blog::Server::API/"TESTING OPTIONS"|TESTING OPTIONS>.
+section L<TESTING OPTIONS|Blog::Server::API/"TESTING OPTIONS">.
 
 =cut
 
